/***************************************************************************
 * MoioChart Library - graphs and charts made easy                         *
 * Copyright (C) 2005 by Silvio Moioli                                     *
 * silvio@moioli.net, http://www.moioli.net                                *  
 *                                                                         *
 * This program is free software; you can redistribute it and/or           *
 * modify it under the terms of the GNU General Public License             *
 * as published by the Free Software Foundation; either version 2          *
 * of the License, or (at your option) any later version.                  *
 *                                                                         *
 * This program is distributed in the hope that it will be useful,         *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 * GNU General Public License for more details.                            *
 *                                                                         *
 * You should have received a copy of the GNU General Public License       *
 * along with this program; if not, write to the Free Software             *
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,              *
 * MA  02110-1301, USA.                                                    *
 ***************************************************************************/

package net.moioli.chart.swing;

import java.util.Collection;
import java.util.Iterator;

/**
 * This is just a stupid wrapper around Collection to solve an incompatibility
 * between the Collection interface and the JPanel class. <br />
 * Both classes, in facts, have a method named size() that makes impossible for
 * a class to both derive JPanel and extend Collection. <br />
 * Since this is needed for JGraph, I created this class that simply renames the
 * Collection size() method into getCollectionSize() leaving everything else
 * unchanged. This is what CompatibleCollection basically does. <br />
 * There's also a companion wrapper that does the opposite to achieve maximum
 * compatibility.
 * 
 * @author Silvio Moioli
 * @version 2005/10/5
 */
public class CompatibleToCollectionWrapper implements Collection {
    /** The wrapped collection object. */
    CompatibleCollection wrapped = null;

    /**
     * Standard constructor, wraps a CompatibleCollection.
     * 
     * @param wrapped
     *            the Collection to be wrapped
     */
    public CompatibleToCollectionWrapper(CompatibleCollection wrapped) {
        this.wrapped = wrapped;
    }

    /**
     * Renames the getCollectionSize() method back to size(), returns the number
     * of elements in the wrapped Collection.
     * 
     * @return the number of elements
     */
    public int size() {
        return this.wrapped.getCollectionSize();
    }

    // Standard Collection methods
    /**
     * @see java.util.Collection#add(Object arg0)
     */
    public boolean add(Object arg0) {
        return this.wrapped.add(arg0);
    }

    /**
     * @see java.util.Collection#addAll(Collection arg0)
     */
    public boolean addAll(Collection arg0) {
        return this.wrapped.addAll(arg0);
    }

    /**
     * @see java.util.Collection#clear()
     */
    public void clear() {
        this.wrapped.clear();
    }

    /**
     * @see java.util.Collection#contains(Object arg0)
     */
    public boolean contains(Object arg0) {
        return this.wrapped.contains(arg0);
    }

    /**
     * @see java.util.Collection#containsAll(Collection arg0)
     */
    public boolean containsAll(Collection arg0) {
        return this.wrapped.containsAll(arg0);
    }

    /**
     * @see java.util.Collection#isEmpty()
     */
    public boolean isEmpty() {
        return this.wrapped.isEmpty();
    }

    /**
     * @see java.util.Collection#iterator()
     */
    public Iterator iterator() {
        return this.wrapped.iterator();
    }

    /**
     * @see java.util.Collection#remove(Object arg0)
     */
    public boolean remove(Object arg0) {
        return this.wrapped.remove(arg0);
    }

    /**
     * @see java.util.Collection#removeAll(Collection arg0)
     */
    public boolean removeAll(Collection arg0) {
        return this.wrapped.removeAll(arg0);
    }

    /**
     * @see java.util.Collection#retainAll(Collection arg0)
     */
    public boolean retainAll(Collection arg0) {
        return this.wrapped.retainAll(arg0);
    }

    /**
     * @see java.util.Collection#toArray()
     */
    public Object[] toArray() {
        return this.wrapped.toArray();
    }

    /**
     * @see java.util.Collection#toArray(Object[] arg0)
     */
    public Object[] toArray(Object[] arg0) {
        return this.wrapped.toArray(arg0);
    }
}