/***************************************************************************
 * MoioChart Library - graphs and charts made easy                         *
 * Copyright (C) 2005 by Silvio Moioli                                     *
 * silvio@moioli.net, http://www.moioli.net                                *  
 *                                                                         *
 * This program is free software; you can redistribute it and/or           *
 * modify it under the terms of the GNU General Public License             *
 * as published by the Free Software Foundation; either version 2          *
 * of the License, or (at your option) any later version.                  *
 *                                                                         *
 * This program is distributed in the hope that it will be useful,         *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 * GNU General Public License for more details.                            *
 *                                                                         *
 * You should have received a copy of the GNU General Public License       *
 * along with this program; if not, write to the Free Software             *
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,              *
 * MA  02110-1301, USA.                                                    *
 ***************************************************************************/

package net.moioli.chart.swing;

import swingwt.awt.Color;
import swingwt.awt.Graphics;
import java.util.Random;

import net.moioli.chart.GraphicsI;

/**
 * This class wraps some Swing basic methods to the GraphicsI interface used in
 * MoioChart for drawing, enabling MoioChart to use Swing.
 * 
 * @author Silvio Moioli
 * @version 2005/10/5
 */
public class SwingGraphicsWrapper implements GraphicsI {
    /** The Swing Graphics wrapped object. */
    private Graphics g = null;

    /** The random number generator for random colors. */
    private Random r = null;

    /** The maximum color index (higher value = brighter) for random colors */
    private int BRIGHTEST = 200;

    /** Default constructor, not available. */
    private SwingGraphicsWrapper() {
        this.r = new Random();
    }

    /**
     * Default constructor, wraps a Swing Graphics object.
     * 
     * @param g
     *            the object to be wrapped.
     */
    public SwingGraphicsWrapper(Graphics g) {
        this();
        this.g = g;
    }

    /**
     * @see GraphicsI#setColor(Object)
     */
    public void setColor(Object c) {
        this.g.setColor((Color) c);
    }

    /**
     * @see GraphicsI#drawLine(int, int, int, int)
     */
    public void drawLine(int x1, int y1, int x2, int y2) {
        this.g.drawLine(x1, y1, x2, y2);
    }

    /**
     * @see GraphicsI#drawString(String, int, int)
     */
    public void drawString(String s, int x, int y) {
        this.g.drawString(s, x, y + this.getStringHeight());
    }

    /**
     * @see GraphicsI#fillPolygon(int[], int[], int)
     */
    public void fillPolygon(int[] xPoints, int[] yPoints, int n) {
        this.g.fillPolygon(xPoints, yPoints, n);
    }

    /**
     * @see GraphicsI#drawCircle(int, int, int)
     */
    public void drawCircle(int x, int y, int radius) {
        int rm = radius / 2;
        int d = radius * 2;
        this.g.drawOval(x - rm, y - rm, d, d);
    }

    /**
     * @see GraphicsI#getStringWidth(String)
     */
    public int getStringWidth(String s) {
        return this.g.getFontMetrics().stringWidth(s);
    }

    /**
     * @see GraphicsI#getStringHeight()
     */
    public int getStringHeight() {
        return this.g.getFontMetrics().getHeight();
    }

    /**
     * @see GraphicsI#getBlackColor()
     */
    public Object getBlackColor() {
        return Color.black;
    }

    /**
     * @see GraphicsI#getRandomColor()
     */
    public Object getRandomColor() {
        return new Color(this.r.nextInt(this.BRIGHTEST), this.r
                .nextInt(this.BRIGHTEST), this.r.nextInt(this.BRIGHTEST));
    }
}